const Peer = window.Peer;

(async function main() {
	const joinTrigger = document.getElementById('js-join-trigger');
	const remoteVideos = document.getElementById('js-remote-stream');
	const roomId = "MomotetsuRoom";
	const messages = document.getElementById('js-messages');
	const meta = document.getElementById('js-meta');
	const sdkSrc = document.querySelector('script[src*=skyway]');

	meta.innerText = `
		UA: ${navigator.userAgent}
		SDK: ${sdkSrc ? sdkSrc.src : 'unknown'}
	`.trim();

	// eslint-disable-next-line require-atomic-updates
	const peer = (window.peer = new Peer({
		key: window.__SKYWAY_KEY__,
		debug: 3,
	}));

	// Register join handler
	joinTrigger.addEventListener('click', () => {
		// Note that you need to ensure the peer has connected to signaling server
		// before using methods of peer instance.
		if (!peer.open) {
			return;
		}

		const room = peer.joinRoom(roomId, {
		});

		room.once('open', () => {
			messages.textContent += '=== You joined ===\n';
		});
		room.on('peerJoin', peerId => {
			messages.textContent += `=== ${peerId} joined ===\n`;
		});

		// Render remote stream for new peer join in the room
		room.on('stream', async stream => {
			//const newVideo = document.createElement('video');
			remoteVideos.srcObject = stream;
			remoteVideos.playsInline = true;
			// mark peerId to find it later at peerLeave event
			remoteVideos.setAttribute('data-peer-id', stream.peerId);
			await remoteVideos.play().catch(console.error);
		});

		room.on('data', ({ data, src }) => {
			// Show a message sent to the room and who sent
			//messages.textContent += `${src}: ${data}\n`;
		});

		// for closing room members
		room.on('peerLeave', peerId => {
			const remoteVideo = remoteVideos.querySelector(
				`[data-peer-id="${peerId}"]`
			);
			remoteVideo.srcObject.getTracks().forEach(track => track.stop());
			remoteVideo.srcObject = null;
			remoteVideo.remove();

			messages.textContent += `=== ${peerId} left ===\n`;
		});

		// for closing myself
		room.once('close', () => {
			sendTrigger.removeEventListener('click', onClickSend);
			messages.textContent += '== You left ===\n';
			Array.from(remoteVideos.children).forEach(remoteVideo => {
				remoteVideo.srcObject.getTracks().forEach(track => track.stop());
				remoteVideo.srcObject = null;
				remoteVideo.remove();
			});
		});
		
		document.addEventListener('keydown', event => {
			//messages.textContent += `${peer.id}: ${event.key}\n`;
			room.send(event.key);
		});
	});

	peer.on('error', console.error);
})();
