const Peer = window.Peer;

(async function main() {
	const joinTrigger = document.getElementById('js-join-trigger');
	const remoteVideos = document.getElementById('js-remote-stream');
	const roomId = "MomotetsuRoom";
	const messages = document.getElementById('js-messages');
	const meta = document.getElementById('js-meta');
	const sdkSrc = document.querySelector('script[src*=skyway]');
	
	const stickTop = document.getElementById('js-stick-top');
	const stickLeft = document.getElementById('js-stick-left');
	const stickRight = document.getElementById('js-stick-right');
	const stickBottom = document.getElementById('js-stick-bottom');
	const hatTop = document.getElementById('js-hat-top');
	const hatLeft = document.getElementById('js-hat-left');
	const hatRight = document.getElementById('js-hat-right');
	const hatBottom = document.getElementById('js-hat-bottom');
	const buttonX = document.getElementById('js-button-x');
	const buttonY = document.getElementById('js-button-y');
	const buttonA = document.getElementById('js-button-a');
	const buttonB = document.getElementById('js-button-b');

	// eslint-disable-next-line require-atomic-updates
	const peer = (window.peer = new Peer({
		key: window.__SKYWAY_KEY__,
		debug: 3,
	}));

	// Register join handler
	joinTrigger.addEventListener('click', () => {
		joinTrigger.style.display ="none";
		
		// Note that you need to ensure the peer has connected to signaling server
		// before using methods of peer instance.
		if (!peer.open) {
			return;
		}

		const room = peer.joinRoom(roomId, {
		});


		// Render remote stream for new peer join in the room
		room.on('stream', async stream => {
			remoteVideos.srcObject = stream;
			remoteVideos.playsInline = true;
			remoteVideos.setAttribute('data-peer-id', stream.peerId);
			await remoteVideos.play().catch(console.error);
		});

		// for closing room members
		room.on('peerLeave', peerId => {
			const remoteVideo = remoteVideos.querySelector(
				`[data-peer-id="${peerId}"]`
			);
			remoteVideo.srcObject.getTracks().forEach(track => track.stop());
			remoteVideo.srcObject = null;
			remoteVideo.remove();

			messages.textContent += `=== ${peerId} left ===\n`;
		});

		// for closing myself
		room.once('close', () => {
			sendTrigger.removeEventListener('click', onClickSend);
			messages.textContent += '== You left ===\n';
			Array.from(remoteVideos.children).forEach(remoteVideo => {
				remoteVideo.srcObject.getTracks().forEach(track => track.stop());
				remoteVideo.srcObject = null;
				remoteVideo.remove();
			});
		});
		
		stickTop.addEventListener('touchend', event => { room.send('w'); });
		stickLeft.addEventListener('touchend', event => { room.send('a'); });
		stickRight.addEventListener('touchend', event => { room.send('d'); });
		stickBottom.addEventListener('touchend', event => { room.send('s'); });
		hatTop.addEventListener('touchend', event => { room.send('w'); });
		hatLeft.addEventListener('touchend', event => { room.send('a'); });
		hatRight.addEventListener('touchend', event => { room.send('d'); });
		hatBottom.addEventListener('touchend', event => { room.send('s'); });
		buttonX.addEventListener('touchend', event => { room.send('i'); });
		buttonY.addEventListener('touchend', event => { room.send('j'); });
		buttonA.addEventListener('touchend', event => { room.send('l'); });
		buttonB.addEventListener('touchend', event => { room.send('k'); });
	});

	peer.on('error', console.error);
})();
