const Peer = window.Peer;

(async function main() {
	const localVideo = document.getElementById('js-local-stream');
	const joinTrigger = document.getElementById('js-join-trigger');
	const roomId = "MomotetsuRoom";
	const messages = document.getElementById('js-messages');
	const meta = document.getElementById('js-meta');
	const sdkSrc = document.querySelector('script[src*=skyway]');
	
	var sock = new WebSocket('ws://127.0.0.1:5001');
	
	sock.addEventListener('open',function(e){
		console.log('socket open');
		sock.send('hello from client');
	});

	sock.addEventListener('message',function(e){
		console.log(e.data);
	});
	

	meta.innerText = `
		UA: ${navigator.userAgent}
		SDK: ${sdkSrc ? sdkSrc.src : 'unknown'}
	`.trim();

	const localStream = await navigator.mediaDevices
		.getUserMedia({
			audio: { 
				sampleRate: {ideal: 44100},
				sampleSize: {ideal: 16},
				echoCancellation: true,
				echoCancellationType: 'system',
				noiseSuppression: false,
				latency: 0.01
			},
			video: { width: {min: 1280, ideal: 1920}, height: {min: 720,ideal: 1080} },
		})
		.catch(console.error);

	// Render local stream
	localVideo.muted = true;
	localVideo.srcObject = localStream;
	localVideo.playsInline = true;
	await localVideo.play().catch(console.error);

	// eslint-disable-next-line require-atomic-updates
	const peer = (window.peer = new Peer({
		key: window.__SKYWAY_KEY__,
		debug: 3,
	}));

	// Register join handler
	peer.on("open", () => {
		// Note that you need to ensure the peer has connected to signaling server
		// before using methods of peer instance.
		if (!peer.open) {
			return;
		}

		const room = peer.joinRoom(roomId, {
			stream: localStream,
		});

		room.once('open', () => {
			messages.textContent += '=== Stream started ===\n';
		});
		room.on('peerJoin', peerId => {
			messages.textContent += `=== ${peerId} joined ===\n`;
		});

		room.on('data', ({ data, src }) => {
			// Show a message sent to the room and who sent
			switch (data) {
				case 'w':
					sock.send(`${src}:HAT TOP`);
					break;
				case 'a':
					sock.send(`${src}:HAT LEFT`);
					break;
				case 's':
					sock.send(`${src}:HAT BOTTOM`);
					break;
				case 'd':
					sock.send(`${src}:HAT RIGHT`);
					break;
				case 'i':
					sock.send(`${src}:Button X`);
					break;
				case 'j':
					sock.send(`${src}:Button Y`);
					break;
				case 'k':
					sock.send(`${src}:Button B`);
					break;
				case 'l':
					sock.send(`${src}:Button A`);
					break;
				case 'w':
					sock.send(`${src}:${data}`);
					break;
				case 'a':
					sock.send(`${src}:${data}`);
					break;
				case 'w':
					sock.send(`${src}:${data}`);
					break;
				case 'a':
					sock.send(`${src}:${data}`);
					break;
				case 'w':
					sock.send(`${src}:${data}`);
					break;
				case 'a':
					sock.send(`${src}:${data}`);
					break;
				case 'w':
					sock.send(`${src}:${data}`);
					break;
				case 'a':
					sock.send(`${src}:${data}`);
					break;
			}
			messages.textContent = `${src}: ${data}\n`;
		});

		// for closing room members
		room.on('peerLeave', peerId => {
			messages.textContent += `=== ${peerId} left ===\n`;
		});

		// for closing myself
		room.once('close', () => {
			//sendTrigger.removeEventListener('click', onClickSend);
			messages.textContent += '=== Stream stoped ===\n';
		});
	});

	peer.on('error', console.error);
})();
