from websocket_server import WebsocketServer
from http.server import HTTPServer, SimpleHTTPRequestHandler
import threading
import serial
import time

SERIAL_PORT = "COM6"
SKIP_COUNT = 0

def startHttpServer():
	with HTTPServer(('localhost', 8000), SimpleHTTPRequestHandler) as server:
		server.serve_forever()

def new_client(client, server):
	print ("new_client:", client['address'])

def message_received(client, server, message):
	global SKIP_COUNT
	try:
		client, cmd = message.split(":")
		print (f"message_received:{client}, {cmd}", )
		if not ser.isProcessing:
			ser.press(cmd)
		else:
			print("Skip")
			SKIP_COUNT += 1
			if SKIP_COUNT > 5:
				ser.closeSerial()
				time.sleep(0.2)
				ser.openSerial(SERIAL_PORT)
				ser.press('Button B')
	except:
		pass

class Serial:
	def __init__(self):
		self.isProcessing = False

	def openSerial(self, portNum):
		self.isProcessing = False
		self.ser = serial.Serial(portNum, 9600)
		self.ser.write(b'RELEASE\r\n')
		
	def closeSerial(self):
		self.ser.close()
	
	def press(self, key):
		if not self.isProcessing:
			self.isProcessing = True
			print(f'INPUT: {key}')
			self.ser.write((key+'\r\n').encode('utf-8'))
			time.sleep(0.05)
			self.ser.write(b'RELEASE\r\n')
			time.sleep(0.05)
			self.isProcessing = False
		

httpServerThread = threading.Thread(target=startHttpServer)
httpServerThread.start()

ser = Serial()
ser.openSerial(SERIAL_PORT)

server = WebsocketServer(port=5001, host='127.0.0.1')
server.set_fn_new_client(new_client)
server.set_fn_message_received(message_received)
server.run_forever()